Comment typos...

François Gouget fgouget at codeweavers.com
Fri Mar 9 20:22:11 CST 2001


Changelog:

   François Gouget <fgouget at codeweavers.com>

 * controls/combo.c,
   dlls/winmm/joystick/joystick.c,
   loader/loadorder.c,
   dlls/winmm/mmio.c

   Fixed spelling/typos in comments


-- 
François Gouget
fgouget at codeweavers.com
-------------- next part --------------
Index: controls/combo.c
===================================================================
RCS file: /home/cvs/wine/wine/controls/combo.c,v
retrieving revision 1.64
diff -u -r1.64 combo.c
--- controls/combo.c	2001/02/20 01:53:12	1.64
+++ controls/combo.c	2001/03/09 01:03:18
@@ -174,7 +174,7 @@
  * This method will calculate the height of the text area of the 
  * combobox.
  * The height of the text area is set in two ways. 
- * It can be set explicitely through a combobox message or through a
+ * It can be set explicitly through a combobox message or through a
  * WM_MEASUREITEM callback.
  * If this is not the case, the height is set to 13 dialog units.
  * This height was determined through experimentation.
Index: dlls/winmm/joystick/joystick.c
===================================================================
RCS file: /home/cvs/wine/wine/dlls/winmm/joystick/joystick.c,v
retrieving revision 1.5
diff -u -r1.5 joystick.c
--- dlls/winmm/joystick/joystick.c	2000/12/19 04:53:20	1.5
+++ dlls/winmm/joystick/joystick.c	2001/03/09 01:03:48
@@ -161,7 +161,7 @@
     lpCaps->wZmax = (nrOfAxes >= 3) ? 0xFFFF : 0;
     lpCaps->wNumButtons = nrOfButtons;
     if (dwSize == sizeof(JOYCAPSA)) {
-	/* since we supose ntOfAxes <= 6 in the following code, do it explicitely */
+	/* since we suppose ntOfAxes <= 6 in the following code, do it explicitly */
 	if (nrOfAxes > 6) nrOfAxes = 6;
 	/* complete 95 structure */
 	lpCaps->wRmin = 0;
Index: dlls/winmm/mmio.c
===================================================================
RCS file: /home/cvs/wine/wine/dlls/winmm/mmio.c,v
retrieving revision 1.20
diff -u -r1.20 mmio.c
--- dlls/winmm/mmio.c	2001/03/05 19:34:17	1.20
+++ dlls/winmm/mmio.c	2001/03/09 01:03:48
@@ -530,7 +530,7 @@
 		WARN("Extension length > 4\n");
 	    lstrcpynA(ext,extStart + 1,min(extEnd-extStart,5));
 	    TRACE("Got extension: %s\n", debugstr_a(ext));
-	    /* FOURCC codes identifying file-extentions must be uppercase */
+	    /* FOURCC codes identifying file-extensions must be uppercase */
 	    ret = mmioStringToFOURCCA(ext, MMIO_TOUPPER);
 	}
     }


More information about the wine-patches mailing list
Index: loader/loadorder.c
===================================================================
RCS file: /home/cvs/wine/wine/loader/loadorder.c,v
retrieving revision 1.40
diff -u -r1.40 loadorder.c
--- loader/loadorder.c	2001/01/10 23:59:26	1.40
+++ loader/loadorder.c	2001/03/09 01:03:48
@@ -409,7 +409,7 @@
 		);
 	}
 
-	/* Read the explicitely defined orders for specific modules as an entire section */
+	/* Read the explicitly defined orders for specific modules as an entire section */
         idx = 0;
         while (PROFILE_EnumWineIniString( "DllOverrides", idx++, key, sizeof(key),
                                           buffer, sizeof(buffer)))
@@ -419,15 +419,15 @@
                 return FALSE;
         }
 
 	/* Add the commandline overrides to the pool */
 	if(!ParseCommandlineOverrides())
 	{
 		MESSAGE(	"Syntax: -dll name[,name[,...]]={native|so|builtin}[,{n|s|b}[,...]][+...]\n"
 			"    - 'name' is the name of any dll without extension\n"
 			"    - the order of loading (native, so and builtin) can be abbreviated\n"
 			"      with the first letter\n"
-			"    - different loadorders for different dlls can be specified by seperating the\n"
-			"      commandline entries with a '+'\n"
+			"    - different loadorders for different dlls can be specified by separating the\n"
+			"      command line entries with a '+'\n"
 			"    Example:\n"
 			"    -dll comdlg32,commdlg=n+shell,shell32=b\n"
 		   );
@@ -419,15 +419,15 @@
         }
 
-	/* Add the commandline overrides to the pool */
+	/* Add the command line overrides to the pool */
 	if(!ParseCommandlineOverrides())
 	{